# version_acronym is either sl or slf
# lower case please!
%define version_acronym sl

%define base_release_version 6
%define minor_release_version 4

# increment this to get the stuff after the - higher
#  helps for making the rolling one go obsolete
%define release_count 0

%define product_family Scientific Linux

# setup pretty name
%if %(echo %{version_acronym} | grep -c 'slf')
%define release_name Ramsey
%define variant_titlecase Fermi
%define variant_lowercase fermi
%define beta_directory slf6rolling

%else
%define release_name Carbon
%define beta_directory 6rolling

%endif


%define debug_package %{nil}
%define full_release_version %{base_release_version}.%{minor_release_version}

# Documentation Specfile
%define HTMLVIEW %(test "%{?dist}" == ".el5" && echo 1 || echo 0)
%define ICONS 1

%define viewer xdg-open

Name:         %{version_acronym}-release-notes
Version:      %{full_release_version}
Release:      %{release_count}
Summary:       Release Notes for Scientific Linux%{?variant_titlecase: %{variant_titlecase}} %{version}
Group:         Documentation
License:       CC-BY-SA, GPL
Source:        sl-release-notes-6.tar.bz2
Source1:       /mnt/src/scientific/6rolling/i386/os/sl-release-notes-%{version}.html
Source2:       http://ftp.scientificlinux.org/linux/scientific/documents/tuv/6/Technical.Notes.%{base_release_version}%{minor_release_version}.html
BuildArch:     noarch
BuildRoot:     %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildRequires: publican >= 2.0
BuildRequires: desktop-file-utils
BuildRequires:    publican-redhat

%if %(echo %{version_acronym} | grep -c 'slf')
Source3:       /mnt/src/slf6rolling/i386/os/Fermi.releasenote
%endif

%if %{HTMLVIEW}
%define viewer htmlview
%define vendor redhat-
%define vendoropt --vendor="Scientific Linux"
Requires:    htmlview
%else
Requires:    xdg-utils
%endif

%description
Scientific Linux%{?variant_titlecase: %{variant_titlecase}} %{version} release notes.
As well as the Upstream Vendors release notes (English).

%prep
%setup -q -n sl-release-notes-6

%build
publican build --formats="html-desktop" --langs=en-US

%install
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT%{_datadir}/applications
mkdir -p $RPM_BUILD_ROOT/usr/share/icons/hicolor/scalable/apps

%if %{ICONS}
for icon in `ls icons/*x*.png`; do
	size=`echo "$icon" | sed -e 's/icons\/\(.*\)\.png/\1/'`;
	mkdir -p $RPM_BUILD_ROOT/usr/share/icons/hicolor/$size/apps
	cp $icon  $RPM_BUILD_ROOT/usr/share/icons/hicolor/$size/apps/release-notes.png;
done
cp icons/icon.svg  $RPM_BUILD_ROOT/usr/share/icons/hicolor/scalable/apps/release-notes.svg;
%else
cp images/icon.svg  $RPM_BUILD_ROOT/usr/share/icons/hicolor/scalable/apps/release-notes.svg;
%endif

cat > TUV.desktop <<'EOF'
[Desktop Entry]
Name=The Upstream Vendor %{version}: Release Notes
Comment=Release Notes for The Upstream Vendor %{version} Release
Exec=%{viewer} %{_docdir}/%{name}-%{version}/tuv.index.html
Icon=release-notes
Categories=Documentation;X-Red-Hat-Base;
Type=Application
Encoding=UTF-8
Terminal=false
EOF

cat > SL.desktop <<'EOF'
[Desktop Entry]
Name=Scientific Linux %{version}: Release Notes
Comment=Release Notes for Scientific Linux %{version}
Exec=%{viewer} %{_docdir}/%{name}-%{version}/index.html
Icon=release-notes
Categories=Documentation;X-Red-Hat-Base;
Type=Application
Encoding=UTF-8
Terminal=false
EOF

%if %(echo %{version_acronym} | grep -c 'slf')
cat > SLF.desktop <<'EOF'
[Desktop Entry]
Name=Scientific Linux Fermi %{version}: Release Notes
Comment=Release Notes for Scientific Linux Fermi %{version}
Exec=%{viewer} %{_docdir}/%{name}-%{version}/index.html
Icon=release-notes
Categories=Documentation;X-Red-Hat-Base;
Type=Application
Encoding=UTF-8
Terminal=false
EOF
%endif

%if %{HTMLVIEW}
desktop-file-install  %{?vendoropt} --dir=${RPM_BUILD_ROOT}%{_datadir}/applications TUV.desktop
desktop-file-install  %{?vendoropt} --dir=${RPM_BUILD_ROOT}%{_datadir}/applications SL.desktop
%if %(echo %{version_acronym} | grep -c 'slf')
desktop-file-install  %{?vendoropt} --dir=${RPM_BUILD_ROOT}%{_datadir}/applications SLF.desktop
%endif
%else
desktop-file-install --dir=${RPM_BUILD_ROOT}%{_datadir}/applications TUV.desktop
desktop-file-install --dir=${RPM_BUILD_ROOT}%{_datadir}/applications SL.desktop
%if %(echo %{version_acronym} | grep -c 'slf')
desktop-file-install --dir=${RPM_BUILD_ROOT}%{_datadir}/applications SLF.desktop
%endif
%endif

# Move the Scientific Linux release notes in
mv tmp/en-US/html-desktop/index.html tmp/en-US/html-desktop/tuv.index.html
cp %{SOURCE2} tmp/en-US/html-desktop/tuv-technotes.html
%if %(echo %{version_acronym} | grep -c 'slf')
echo '<html><head><title>Scientific Linux Fermi Release Notes</title></head><body><pre>' > tmp/en-US/html-desktop/index.html
echo '' >> tmp/en-US/html-desktop/index.html
cat %{SOURCE3} >> tmp/en-US/html-desktop/index.html
echo '' >> tmp/en-US/html-desktop/index.html
echo '</pre></body></html>' >> tmp/en-US/html-desktop/index.html

cp %{SOURCE1} tmp/en-US/html-desktop/sl-index.html
%else
cp %{SOURCE1} tmp/en-US/html-desktop/index.html
%endif

# Update Icon cache if it exists
%post
touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :

%postun
if [ $1 -eq 0 ] ; then
    touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi

%posttrans
gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :

%clean
rm -rf $RPM_BUILD_ROOT

%files
%defattr(-,root,root,-)
%doc tmp/en-US/html-desktop/*
%if %{ICONS}
/usr/share/icons/hicolor/*
%endif
%{_datadir}/applications/TUV.desktop
%{_datadir}/applications/SL.desktop
%if %(echo %{version_acronym} | grep -c 'slf')
%{_datadir}/applications/SLF.desktop
%endif

%changelog
* Tue Jul 17 2012 Pat Riehecky <riehecky@fnal.gov> - 6.3-2
- Final release notes for 6.3

* Tue Jul 17 2012 Pat Riehecky <riehecky@fnal.gov> - 6.3-1
- Updated for 6.3

* Tue Jul 17 2012 Pat Riehecky <riehecky@fnal.gov> - 6.3-0
- Moved to TUV 6.3 release notes
- Added TUV Technical notes

* Tue Feb 6 2012 Pat Riehecky <riehecky@fnal.gov> - 6.2-3
- SL 6.2 final release notes.

* Tue Jan 30 2012 Pat Riehecky <riehecky@fnal.gov> - 6.2-2
- Updated notes to match current SL 6.2 change set
- Refactored the HTML to be a bit simpler

* Tue Jan 10 2012 Pat Riehecky <riehecky@fnal.gov> - 6.2-0
- Initial SL 6.2 release notes

* Mon Jul 25 2011 Troy Dawson <dawson@fnal.gov> - 6.1-1
- SL 6.1 final release notes.

* Wed Mar 02 2011 Troy Dawson <dawson@fnal.gov> - 6.1-0.1.rolling
- Initial release for SL 6.1

* Wed Mar 02 2011 Troy Dawson <dawson@fnal.gov> - 6.0-1
- Final release notes

* Thu Dec 02 2010 Troy Dawson <dawson@fnal.gov> - 6.0-0.1.rolling
- Initial release
- Including TUV release notes, unchanged
- Adding blank SL release notes.
